pub type ExecuteMsg = ExecuteMsg<DexExecuteMsg>;Expand description
Top-level Abstract Adapter execute message. This is the message that is passed to the execute entrypoint of the smart-contract.
Aliased Type
pub enum ExecuteMsg {
Base(BaseExecuteMsg),
Module(AdapterRequestMsg<DexExecuteMsg>),
IbcCallback(IbcResponseMsg),
ModuleIbc(ModuleIbcMsg),
}Variants
Base(BaseExecuteMsg)
A configuration message, defined by the base.
Module(AdapterRequestMsg<DexExecuteMsg>)
An app request defined by a base consumer.
IbcCallback(IbcResponseMsg)
IbcReceive to process IBC callbacks In order to trust this, the apps and adapters verify this comes from the ibc-client contract.
ModuleIbc(ModuleIbcMsg)
ModuleIbc endpoint to receive messages from modules on other chains
In order to trust this, the apps and adapters verify this comes from the ibc-host contract.
They should also trust the sending chain